==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/system/IMEConversionMode.js <==
joo.classLoader.prepare("package flash.system",/* {*/


/**
 * This class contains constants for use with the <code>IME.conversionMode</code> property. Setting <code>conversionMode</code> to either <code>ALPHANUMERIC_FULL</code> or <code>JAPANESE_KATAKANA_FULL</code> causes the player to use a full width font, whereas using <code>ALPHANUMERIC_HALF</code> or <code>JAPANESE_KATAKANA_HALF</code> uses a half width font.
 * @see IME#conversionMode
 *
 */
"public final class IMEConversionMode",1,function($$private){;return[ 
  /**
   * The string <code>"ALPHANUMERIC_FULL"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with all IMEs. Use the syntax <code>IMEConversionMode.ALPHANUMERIC_FULL</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ ALPHANUMERIC_FULL/*:String*/ : "ALPHANUMERIC_FULL"},
  /**
   * The string <code>"ALPHANUMERIC_HALF"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with all IMEs. Use the syntax <code>IMEConversionMode.ALPHANUMERIC_HALF</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ ALPHANUMERIC_HALF/*:String*/ : "ALPHANUMERIC_HALF"},
  /**
   * The string <code>"CHINESE"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with simplified and traditional Chinese IMEs. Use the syntax <code>IMEConversionMode.CHINESE</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ CHINESE/*:String*/ : "CHINESE"},
  /**
   * The string <code>"JAPANESE_HIRAGANA"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_HIRAGANA</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_HIRAGANA/*:String*/ : "JAPANESE_HIRAGANA"},
  /**
   * The string <code>"JAPANESE_KATAKANA_FULL"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_KATAKANA_FULL</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_KATAKANA_FULL/*:String*/ : "JAPANESE_KATAKANA_FULL"},
  /**
   * The string <code>"JAPANESE_KATAKANA_HALF"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_KATAKANA_HALF</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_KATAKANA_HALF/*:String*/ : "JAPANESE_KATAKANA_HALF"},
  /**
   * The string <code>"KOREAN"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Korean IMEs. Use the syntax <code>IMEConversionMode.KOREAN</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ KOREAN/*:String*/ : "KOREAN"},
  /**
   * The string <code>"UNKNOWN"</code>, which can be returned by a call to the <code>IME.conversionMode</code> property. This value cannot be set, and is returned only if the player is unable to identify the currently active IME. Use the syntax <code>IMEConversionMode.UNKNOWN</code>.
   * @see IME#conversionMode
   *
   */
  "public static const",{ UNKNOWN/*:String*/ : "UNKNOWN"},
];},[],[], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/system/IMEConversionMode.js <==
joo.classLoader.prepare("package flash.system",/* {*/


/**
 * This class contains constants for use with the <code>IME.conversionMode</code> property. Setting <code>conversionMode</code> to either <code>ALPHANUMERIC_FULL</code> or <code>JAPANESE_KATAKANA_FULL</code> causes the player to use a full width font, whereas using <code>ALPHANUMERIC_HALF</code> or <code>JAPANESE_KATAKANA_HALF</code> uses a half width font.
 * @see IME#conversionMode
 *
 */
"public final class IMEConversionMode",1,function($$private){return[ 
  /**
   * The string <code>"ALPHANUMERIC_FULL"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with all IMEs. Use the syntax <code>IMEConversionMode.ALPHANUMERIC_FULL</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ ALPHANUMERIC_FULL/*:String*/ : "ALPHANUMERIC_FULL"},
  /**
   * The string <code>"ALPHANUMERIC_HALF"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with all IMEs. Use the syntax <code>IMEConversionMode.ALPHANUMERIC_HALF</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ ALPHANUMERIC_HALF/*:String*/ : "ALPHANUMERIC_HALF"},
  /**
   * The string <code>"CHINESE"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with simplified and traditional Chinese IMEs. Use the syntax <code>IMEConversionMode.CHINESE</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ CHINESE/*:String*/ : "CHINESE"},
  /**
   * The string <code>"JAPANESE_HIRAGANA"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_HIRAGANA</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_HIRAGANA/*:String*/ : "JAPANESE_HIRAGANA"},
  /**
   * The string <code>"JAPANESE_KATAKANA_FULL"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_KATAKANA_FULL</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_KATAKANA_FULL/*:String*/ : "JAPANESE_KATAKANA_FULL"},
  /**
   * The string <code>"JAPANESE_KATAKANA_HALF"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Japanese IMEs. Use the syntax <code>IMEConversionMode.JAPANESE_KATAKANA_HALF</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ JAPANESE_KATAKANA_HALF/*:String*/ : "JAPANESE_KATAKANA_HALF"},
  /**
   * The string <code>"KOREAN"</code>, for use with the <code>IME.conversionMode</code> property. This constant is used with Korean IMEs. Use the syntax <code>IMEConversionMode.KOREAN</code>.
   * @see IME#conversionMode
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7cd5.html Using the IME class
   *
   */
  "public static const",{ KOREAN/*:String*/ : "KOREAN"},
  /**
   * The string <code>"UNKNOWN"</code>, which can be returned by a call to the <code>IME.conversionMode</code> property. This value cannot be set, and is returned only if the player is unable to identify the currently active IME. Use the syntax <code>IMEConversionMode.UNKNOWN</code>.
   * @see IME#conversionMode
   *
   */
  "public static const",{ UNKNOWN/*:String*/ : "UNKNOWN"},
undefined];},[],[], "0.8.0", "0.9.12"
);
